// from
// http://gcc.gnu.org/onlinedocs/gcc-4.7.0/gcc/X86-Built_002din-Functions.html

__CPROVER_Float128 __builtin_fabsq(__CPROVER_Float128);
__CPROVER_Float128 __builtin_copysignq(__CPROVER_Float128, __CPROVER_Float128);
void __builtin_ia32_pause();
__CPROVER_Float128 __builtin_infq(void);
__CPROVER_Float128 __builtin_huge_valq(void);
__gcc_v8qi __builtin_ia32_paddb(__gcc_v8qi, __gcc_v8qi);
__gcc_v4hi __builtin_ia32_paddw(__gcc_v4hi, __gcc_v4hi);
__gcc_v2si __builtin_ia32_paddd(__gcc_v2si, __gcc_v2si);
__gcc_v8qi __builtin_ia32_psubb(__gcc_v8qi, __gcc_v8qi);
__gcc_v4hi __builtin_ia32_psubw(__gcc_v4hi, __gcc_v4hi);
__gcc_v2si __builtin_ia32_psubd(__gcc_v2si, __gcc_v2si);
__gcc_v8qi __builtin_ia32_paddsb(__gcc_v8qi, __gcc_v8qi);
__gcc_v4hi __builtin_ia32_paddsw(__gcc_v4hi, __gcc_v4hi);
__gcc_v8qi __builtin_ia32_psubsb(__gcc_v8qi, __gcc_v8qi);
__gcc_v4hi __builtin_ia32_psubsw(__gcc_v4hi, __gcc_v4hi);
__gcc_v8qi __builtin_ia32_paddusb(__gcc_v8qi, __gcc_v8qi);
__gcc_v4hi __builtin_ia32_paddusw(__gcc_v4hi, __gcc_v4hi);
__gcc_v8qi __builtin_ia32_psubusb(__gcc_v8qi, __gcc_v8qi);
__gcc_v4hi __builtin_ia32_psubusw(__gcc_v4hi, __gcc_v4hi);
__gcc_v4hi __builtin_ia32_pmullw(__gcc_v4hi, __gcc_v4hi);
__gcc_v4hi __builtin_ia32_pmulhw(__gcc_v4hi, __gcc_v4hi);

__gcc_v2si __builtin_ia32_pand(__gcc_v2si, __gcc_v2si); // maybe di
__gcc_v2si __builtin_ia32_pandn(__gcc_v2si, __gcc_v2si); // maybe di
__gcc_v2si __builtin_ia32_por(__gcc_v2si, __gcc_v2si); // maybe di
__gcc_v2si __builtin_ia32_pxor(__gcc_v2si, __gcc_v2si); // maybe di
//__gcc_di __builtin_ia32_pand(__gcc_di, __gcc_di);
//__gcc_di __builtin_ia32_pandn(__gcc_di, __gcc_di);
//__gcc_di __builtin_ia32_por(__gcc_di, __gcc_di);
//__gcc_di __builtin_ia32_pxor(__gcc_di, __gcc_di);

__gcc_v8qi __builtin_ia32_pcmpeqb(__gcc_v8qi, __gcc_v8qi);
__gcc_v4hi __builtin_ia32_pcmpeqw(__gcc_v4hi, __gcc_v4hi);
__gcc_v2si __builtin_ia32_pcmpeqd(__gcc_v2si, __gcc_v2si);
__gcc_v8qi __builtin_ia32_pcmpgtb(__gcc_v8qi, __gcc_v8qi);
__gcc_v4hi __builtin_ia32_pcmpgtw(__gcc_v4hi, __gcc_v4hi);
__gcc_v2si __builtin_ia32_pcmpgtd(__gcc_v2si, __gcc_v2si);
__gcc_v8qi __builtin_ia32_punpckhbw(__gcc_v8qi, __gcc_v8qi);
__gcc_v4hi __builtin_ia32_punpckhwd(__gcc_v4hi, __gcc_v4hi);
__gcc_v2si __builtin_ia32_punpckhdq(__gcc_v2si, __gcc_v2si);
__gcc_v8qi __builtin_ia32_punpcklbw(__gcc_v8qi, __gcc_v8qi);
__gcc_v4hi __builtin_ia32_punpcklwd(__gcc_v4hi, __gcc_v4hi);
__gcc_v2si __builtin_ia32_punpckldq(__gcc_v2si, __gcc_v2si);
__gcc_v8qi __builtin_ia32_packsswb(__gcc_v4hi, __gcc_v4hi);
__gcc_v4hi __builtin_ia32_packssdw(__gcc_v2si, __gcc_v2si);
__gcc_v8qi __builtin_ia32_packuswb(__gcc_v4hi, __gcc_v4hi);
__gcc_v4hi __builtin_ia32_psllw(__gcc_v4hi, __gcc_v4hi);
__gcc_v2si __builtin_ia32_pslld(__gcc_v2si, __gcc_v2si);
__gcc_v1di __builtin_ia32_psllq(__gcc_v1di, __gcc_v1di);
__gcc_v4hi __builtin_ia32_psrlw(__gcc_v4hi, __gcc_v4hi);
__gcc_v2si __builtin_ia32_psrld(__gcc_v2si, __gcc_v2si);
__gcc_v1di __builtin_ia32_psrlq(__gcc_v1di, __gcc_v1di);
__gcc_v4hi __builtin_ia32_psraw(__gcc_v4hi, __gcc_v4hi);
__gcc_v2si __builtin_ia32_psrad(__gcc_v2si, __gcc_v2si);
__gcc_v4hi __builtin_ia32_psllwi(__gcc_v4hi, int);
__gcc_v2si __builtin_ia32_pslldi(__gcc_v2si, int);
__gcc_v1di __builtin_ia32_psllqi(__gcc_v1di, int);
__gcc_v4hi __builtin_ia32_psrlwi(__gcc_v4hi, int);
__gcc_v2si __builtin_ia32_psrldi(__gcc_v2si, int);
__gcc_v1di __builtin_ia32_psrlqi(__gcc_v1di, int);
__gcc_v4hi __builtin_ia32_psrawi(__gcc_v4hi, int);
__gcc_v2si __builtin_ia32_psradi(__gcc_v2si, int);
__gcc_v4hi __builtin_ia32_pmulhuw(__gcc_v4hi, __gcc_v4hi);
__gcc_v8qi __builtin_ia32_pavgb(__gcc_v8qi, __gcc_v8qi);
__gcc_v4hi __builtin_ia32_pavgw(__gcc_v4hi, __gcc_v4hi);
__gcc_v1di __builtin_ia32_psadbw(__gcc_v8qi, __gcc_v8qi);
__gcc_v8qi __builtin_ia32_pmaxub(__gcc_v8qi, __gcc_v8qi);
__gcc_v4hi __builtin_ia32_pmaxsw(__gcc_v4hi, __gcc_v4hi);
__gcc_v8qi __builtin_ia32_pminub(__gcc_v8qi, __gcc_v8qi);
__gcc_v4hi __builtin_ia32_pminsw(__gcc_v4hi, __gcc_v4hi);
int __builtin_ia32_pextrw(__gcc_v4hi, int);
__gcc_v4hi __builtin_ia32_pinsrw(__gcc_v4hi, int, int);
int __builtin_ia32_pmovmskb(__gcc_v8qi);
void __builtin_ia32_maskmovq(__gcc_v8qi, __gcc_v8qi, char*);

// clang uses the following:
// void __builtin_ia32_movntq(__gcc_v1di*, __gcc_v1di);
 //
 // GCC uses this:
// void __builtin_ia32_movntq(__gcc_di*, __gcc_di);
 //
 // So, we use:
void __builtin_ia32_movntq(void*, ...);

void __builtin_ia32_sfence();
int __builtin_ia32_comieq(__gcc_v4sf, __gcc_v4sf);
int __builtin_ia32_comineq(__gcc_v4sf, __gcc_v4sf);
int __builtin_ia32_comilt(__gcc_v4sf, __gcc_v4sf);
int __builtin_ia32_comile(__gcc_v4sf, __gcc_v4sf);
int __builtin_ia32_comigt(__gcc_v4sf, __gcc_v4sf);
int __builtin_ia32_comige(__gcc_v4sf, __gcc_v4sf);
int __builtin_ia32_ucomieq(__gcc_v4sf, __gcc_v4sf);
int __builtin_ia32_ucomineq(__gcc_v4sf, __gcc_v4sf);
int __builtin_ia32_ucomilt(__gcc_v4sf, __gcc_v4sf);
int __builtin_ia32_ucomile(__gcc_v4sf, __gcc_v4sf);
int __builtin_ia32_ucomigt(__gcc_v4sf, __gcc_v4sf);
int __builtin_ia32_ucomige(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_addps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_subps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_mulps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_divps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_addss(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_subss(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_mulss(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_divss(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpeqps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpltps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpleps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpgtps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpgeps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpunordps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpneqps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpnltps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpnleps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpngtps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpngeps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpordps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpeqss(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpltss(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpless(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpunordss(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpneqss(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpnlts(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpnless(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cmpordss(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_maxps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_maxss(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_minps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_minss(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_andps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_andnps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_orps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_xorps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_movss(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_movhlps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_movlhps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_unpckhps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_unpcklps(__gcc_v4sf, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_cvtpi2ps(__gcc_v4sf, __gcc_v2si);
__gcc_v4sf __builtin_ia32_cvtsi2ss(__gcc_v4sf, int);
__gcc_v2si __builtin_ia32_cvtps2pi(__gcc_v4sf);
int __builtin_ia32_cvtss2si(__gcc_v4sf);
__gcc_v2si __builtin_ia32_cvttps2pi(__gcc_v4sf);
int __builtin_ia32_cvttss2si(__gcc_v4sf);
__gcc_v4sf __builtin_ia32_rcpps(__gcc_v4sf);
__gcc_v4sf __builtin_ia32_rsqrtps(__gcc_v4sf);
__gcc_v4sf __builtin_ia32_sqrtps(__gcc_v4sf);
__gcc_v4sf __builtin_ia32_rcpss(__gcc_v4sf);
__gcc_v4sf __builtin_ia32_rsqrtss(__gcc_v4sf);
__gcc_v4sf __builtin_ia32_sqrtss(__gcc_v4sf);
__gcc_v4sf __builtin_ia32_shufps(__gcc_v4sf, __gcc_v4sf, int);
void __builtin_ia32_movntps(float*, __gcc_v4sf);
int __builtin_ia32_movmskps(__gcc_v4sf);
__gcc_v4sf __builtin_ia32_loadaps(float*);
void __builtin_ia32_storeaps(float*, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_loadups(const float*);
void __builtin_ia32_storeups(float*, __gcc_v4sf);
__gcc_v4sf __builtin_ia32_loadsss(float*);
void __builtin_ia32_storess(float*, __gcc_v4sf);

// clang uses these:
// __gcc_v4sf __builtin_ia32_loadhps(__gcc_v4sf, const __gcc_v2si*);
// __gcc_v4sf __builtin_ia32_loadlps(__gcc_v4sf, const __gcc_v2si*);
// void __builtin_ia32_storehps(__gcc_v2si*, __gcc_v4sf);
// void __builtin_ia32_storelps(__gcc_v2si*, __gcc_v4sf);
//
// but GCC uses:
// __gcc_v4sf __builtin_ia32_loadhps(__gcc_v4sf, const __gcc_v2sf*);
// __gcc_v4sf __builtin_ia32_loadlps(__gcc_v4sf, const __gcc_v2sf*);
// void __builtin_ia32_storehps(__gcc_v2sf*, __gcc_v4sf);
// void __builtin_ia32_storelps(__gcc_v2sf*, __gcc_v4sf);
//
// So we use:
__gcc_v4sf __builtin_ia32_loadhps(__gcc_v4sf, const void*);
__gcc_v4sf __builtin_ia32_loadlps(__gcc_v4sf, const void*);
void __builtin_ia32_storehps(void*, __gcc_v4sf);
void __builtin_ia32_storelps(void*, __gcc_v4sf);

__gcc_v4si __builtin_ia32_loadlv4si(const __gcc_v2si*);
void __builtin_ia32_storelv4si(__gcc_v2si*, __gcc_v4si);
__gcc_v4si __builtin_ia32_movqv4si(__gcc_v4si);

int __builtin_ia32_comisdeq(__gcc_v2df, __gcc_v2df);
int __builtin_ia32_comisdlt(__gcc_v2df, __gcc_v2df);
int __builtin_ia32_comisdle(__gcc_v2df, __gcc_v2df);
int __builtin_ia32_comisdgt(__gcc_v2df, __gcc_v2df);
int __builtin_ia32_comisdge(__gcc_v2df, __gcc_v2df);
int __builtin_ia32_comisdneq(__gcc_v2df, __gcc_v2df);
int __builtin_ia32_ucomisdeq(__gcc_v2df, __gcc_v2df);
int __builtin_ia32_ucomisdlt(__gcc_v2df, __gcc_v2df);
int __builtin_ia32_ucomisdle(__gcc_v2df, __gcc_v2df);
int __builtin_ia32_ucomisdgt(__gcc_v2df, __gcc_v2df);
int __builtin_ia32_ucomisdge(__gcc_v2df, __gcc_v2df);
int __builtin_ia32_ucomisdneq(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpeqpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpltpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmplepd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpgtpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpgepd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpunordpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpneqpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpnltpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpnlepd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpngtpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpngepd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpordpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpeqsd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpltsd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmplesd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpunordsd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpneqsd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpnltsd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpnlesd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_cmpordsd(__gcc_v2df, __gcc_v2df);
__gcc_v1di __builtin_ia32_paddq(__gcc_v1di, __gcc_v1di);
__gcc_v1di __builtin_ia32_psubq(__gcc_v1di, __gcc_v1di);
__gcc_v2df __builtin_ia32_addpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_subpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_mulpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_divpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_addsd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_subsd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_mulsd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_divsd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_minpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_maxpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_minsd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_maxsd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_andpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_andnpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_orpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_xorpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_movsd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_unpckhpd(__gcc_v2df, __gcc_v2df);
__gcc_v2df __builtin_ia32_unpcklpd(__gcc_v2df, __gcc_v2df);
__gcc_v16qi __builtin_ia32_paddb128(__gcc_v16qi, __gcc_v16qi);
__gcc_v8hi __builtin_ia32_paddw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_paddd128(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_paddq128(__gcc_v2di, __gcc_v2di);
__gcc_v16qi __builtin_ia32_psubb128(__gcc_v16qi, __gcc_v16qi);
__gcc_v8hi __builtin_ia32_psubw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_psubd128(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_psubq128(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_pmullw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v8hi __builtin_ia32_pmulhw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v2di __builtin_ia32_pand128(__gcc_v2di, __gcc_v2di);
__gcc_v2di __builtin_ia32_pandn128(__gcc_v2di, __gcc_v2di);
__gcc_v2di __builtin_ia32_por128(__gcc_v2di, __gcc_v2di);
__gcc_v2di __builtin_ia32_pxor128(__gcc_v2di, __gcc_v2di);
__gcc_v16qi __builtin_ia32_pavgb128(__gcc_v16qi, __gcc_v16qi);
__gcc_v8hi __builtin_ia32_pavgw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_pcmpeqb128(__gcc_v16qi, __gcc_v16qi);
__gcc_v8hi __builtin_ia32_pcmpeqw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_pcmpeqd128(__gcc_v4si, __gcc_v4si);
__gcc_v16qi __builtin_ia32_pcmpgtb128(__gcc_v16qi, __gcc_v16qi);
__gcc_v8hi __builtin_ia32_pcmpgtw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_pcmpgtd128(__gcc_v4si, __gcc_v4si);
__gcc_v16qi __builtin_ia32_pmaxub128(__gcc_v16qi, __gcc_v16qi);
__gcc_v8hi __builtin_ia32_pmaxsw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_pminub128(__gcc_v16qi, __gcc_v16qi);
__gcc_v8hi __builtin_ia32_pminsw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_punpckhbw128(__gcc_v16qi, __gcc_v16qi);
__gcc_v8hi __builtin_ia32_punpckhwd128(__gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_punpckhdq128(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_punpckhqdq128(__gcc_v2di, __gcc_v2di);
__gcc_v16qi __builtin_ia32_punpcklbw128(__gcc_v16qi, __gcc_v16qi);
__gcc_v8hi __builtin_ia32_punpcklwd128(__gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_punpckldq128(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_punpcklqdq128(__gcc_v2di, __gcc_v2di);
__gcc_v16qi __builtin_ia32_packsswb128(__gcc_v8hi, __gcc_v8hi);
__gcc_v8hi __builtin_ia32_packssdw128(__gcc_v4si, __gcc_v4si);
__gcc_v16qi __builtin_ia32_packuswb128(__gcc_v8hi, __gcc_v8hi);
__gcc_v8hi __builtin_ia32_pmulhuw128(__gcc_v8hi, __gcc_v8hi);
void __builtin_ia32_maskmovdqu(__gcc_v16qi, __gcc_v16qi, char*);
__gcc_v2df __builtin_ia32_loadupd(const double*);
void __builtin_ia32_storeupd(double*, __gcc_v2df);
__gcc_v2df __builtin_ia32_loadhpd(__gcc_v2df, const double*);
__gcc_v2df __builtin_ia32_loadlpd(__gcc_v2df, const double*);
int __builtin_ia32_movmskpd(__gcc_v2df);
int __builtin_ia32_pmovmskb128(__gcc_v16qi);
void __builtin_ia32_movnti(int*, int);
void __builtin_ia32_movnti64(long long*, long long);
void __builtin_ia32_movntpd(double*, __gcc_v2df);
void __builtin_ia32_movntdq(__gcc_v2di*, __gcc_v2di);
__gcc_v4si __builtin_ia32_pshufd(__gcc_v4si, int);
__gcc_v8hi __builtin_ia32_pshuflw(__gcc_v8hi, int);
__gcc_v8hi __builtin_ia32_pshufhw(__gcc_v8hi, int);
__gcc_v2di __builtin_ia32_psadbw128(__gcc_v16qi, __gcc_v16qi);
__gcc_v2df __builtin_ia32_sqrtpd(__gcc_v2df);
__gcc_v2df __builtin_ia32_sqrtsd(__gcc_v2df);
__gcc_v2df __builtin_ia32_shufpd(__gcc_v2df, __gcc_v2df, int);
__gcc_v2df __builtin_ia32_cvtdq2pd(__gcc_v4si);
__gcc_v4sf __builtin_ia32_cvtdq2ps(__gcc_v4si);
__gcc_v4si __builtin_ia32_cvtpd2dq(__gcc_v2df);
__gcc_v2si __builtin_ia32_cvtpd2pi(__gcc_v2df);
__gcc_v4sf __builtin_ia32_cvtpd2ps(__gcc_v2df);
__gcc_v4si __builtin_ia32_cvttpd2dq(__gcc_v2df);
__gcc_v2si __builtin_ia32_cvttpd2pi(__gcc_v2df);
__gcc_v2df __builtin_ia32_cvtpi2pd(__gcc_v2si);
int __builtin_ia32_cvtsd2si(__gcc_v2df);
int __builtin_ia32_cvttsd2si(__gcc_v2df);
long long __builtin_ia32_cvtsd2si64(__gcc_v2df);
long long __builtin_ia32_cvttsd2si64(__gcc_v2df);
__gcc_v4si __builtin_ia32_cvtps2dq(__gcc_v4sf);
__gcc_v2df __builtin_ia32_cvtps2pd(__gcc_v4sf);
__gcc_v4si __builtin_ia32_cvttps2dq(__gcc_v4sf);
__gcc_v2df __builtin_ia32_cvtsi2sd(__gcc_v2df, int);
__gcc_v2df __builtin_ia32_cvtsi642sd(__gcc_v2df, long long);
__gcc_v4sf __builtin_ia32_cvtsd2ss(__gcc_v4sf, __gcc_v2df);
__gcc_v2df __builtin_ia32_cvtss2sd(__gcc_v2df, __gcc_v4sf);
void __builtin_ia32_clflush(const void*);
void __builtin_ia32_lfence();
void __builtin_ia32_mfence(void);
__gcc_v16qi __builtin_ia32_loaddqu(const char*);
void __builtin_ia32_storedqu(char*, __gcc_v16qi);
__gcc_v1di __builtin_ia32_pmuludq(__gcc_v2si, __gcc_v2si);
__gcc_v2di __builtin_ia32_pmuludq128(__gcc_v4si, __gcc_v4si);
__gcc_v8hi __builtin_ia32_psllw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_pslld128(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_psllq128(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_psrlw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_psrld128(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_psrlq128(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_psraw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_psrad128(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_pslldqi128(__gcc_v2di, int);
__gcc_v8hi __builtin_ia32_psllwi128(__gcc_v8hi, int);
__gcc_v4si __builtin_ia32_pslldi128(__gcc_v4si, int);
__gcc_v2di __builtin_ia32_psllqi128(__gcc_v2di, int);
__gcc_v2di __builtin_ia32_psrldqi128(__gcc_v2di, int);
__gcc_v8hi __builtin_ia32_psrlwi128(__gcc_v8hi, int);
__gcc_v4si __builtin_ia32_psrldi128(__gcc_v4si, int);
__gcc_v2di __builtin_ia32_psrlqi128(__gcc_v2di, int);
__gcc_v8hi __builtin_ia32_psrawi128(__gcc_v8hi, int);
__gcc_v4si __builtin_ia32_psradi128(__gcc_v4si, int);
__gcc_v4si __builtin_ia32_pmaddwd128(__gcc_v8hi, __gcc_v8hi);
__gcc_v2di __builtin_ia32_movq128(__gcc_v2di);
__gcc_v2df __builtin_ia32_addsubpd(__gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_addsubps(__gcc_v4sf, __gcc_v4sf);
__gcc_v2df __builtin_ia32_haddpd(__gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_haddps(__gcc_v4sf, __gcc_v4sf);
__gcc_v2df __builtin_ia32_hsubpd(__gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_hsubps(__gcc_v4sf, __gcc_v4sf);
__gcc_v16qi __builtin_ia32_lddqu(const char*);
void __builtin_ia32_monitor(void*, unsigned int, unsigned int);
__gcc_v2df __builtin_ia32_movddup(__gcc_v2df);
__gcc_v4sf __builtin_ia32_movshdup(__gcc_v4sf);
__gcc_v4sf __builtin_ia32_movsldup(__gcc_v4sf);
void __builtin_ia32_mwait(unsigned int, unsigned int);
__gcc_v2df __builtin_ia32_loadddup(double const*);
__gcc_v2si __builtin_ia32_phaddd(__gcc_v2si, __gcc_v2si);
__gcc_v4hi __builtin_ia32_phaddw(__gcc_v4hi, __gcc_v4hi);
__gcc_v4hi __builtin_ia32_phaddsw(__gcc_v4hi, __gcc_v4hi);
__gcc_v2si __builtin_ia32_phsubd(__gcc_v2si, __gcc_v2si);
__gcc_v4hi __builtin_ia32_phsubw(__gcc_v4hi, __gcc_v4hi);
__gcc_v4hi __builtin_ia32_phsubsw(__gcc_v4hi, __gcc_v4hi);
__gcc_v4hi __builtin_ia32_pmaddubsw(__gcc_v8qi, __gcc_v8qi);
__gcc_v4hi __builtin_ia32_pmulhrsw(__gcc_v4hi, __gcc_v4hi);
__gcc_v8qi __builtin_ia32_pshufb(__gcc_v8qi, __gcc_v8qi);
__gcc_v8qi __builtin_ia32_psignb(__gcc_v8qi, __gcc_v8qi);
__gcc_v2si __builtin_ia32_psignd(__gcc_v2si, __gcc_v2si);
__gcc_v4hi __builtin_ia32_psignw(__gcc_v4hi, __gcc_v4hi);
__gcc_v1di __builtin_ia32_palignr(__gcc_v1di, __gcc_v1di, int);
__gcc_v8qi __builtin_ia32_pabsb(__gcc_v8qi);
__gcc_v2si __builtin_ia32_pabsd(__gcc_v2si);
__gcc_v4hi __builtin_ia32_pabsw(__gcc_v4hi);
__gcc_v4si __builtin_ia32_phaddd128(__gcc_v4si, __gcc_v4si);
__gcc_v8hi __builtin_ia32_phaddw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v8hi __builtin_ia32_phaddsw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_phsubd128(__gcc_v4si, __gcc_v4si);
__gcc_v8hi __builtin_ia32_phsubw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v8hi __builtin_ia32_phsubsw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v8hi __builtin_ia32_pmaddubsw128(__gcc_v16qi, __gcc_v16qi);
__gcc_v8hi __builtin_ia32_pmulhrsw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_pshufb128(__gcc_v16qi, __gcc_v16qi);
__gcc_v16qi __builtin_ia32_psignb128(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_psignd128(__gcc_v4si, __gcc_v4si);
__gcc_v8hi __builtin_ia32_psignw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v2di __builtin_ia32_palignr128(__gcc_v2di, __gcc_v2di, int);
__gcc_v16qi __builtin_ia32_pabsb128(__gcc_v16qi);
__gcc_v4si __builtin_ia32_pabsd128(__gcc_v4si);
__gcc_v8hi __builtin_ia32_pabsw128(__gcc_v8hi);
__gcc_v2df __builtin_ia32_blendpd(__gcc_v2df, __gcc_v2df, int);
__gcc_v4sf __builtin_ia32_blendps(__gcc_v4sf, __gcc_v4sf, int);
__gcc_v2df __builtin_ia32_blendvpd(__gcc_v2df, __gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_blendvps(__gcc_v4sf, __gcc_v4sf, __gcc_v4sf);
__gcc_v2df __builtin_ia32_dppd(__gcc_v2df, __gcc_v2df, int);
__gcc_v4sf __builtin_ia32_dpps(__gcc_v4sf, __gcc_v4sf, int);
__gcc_v4sf __builtin_ia32_insertps128(__gcc_v4sf, __gcc_v4sf, int);
__gcc_v2di __builtin_ia32_movntdqa(__gcc_v2di*);
__gcc_v16qi __builtin_ia32_mpsadbw128(__gcc_v16qi, __gcc_v16qi, int);
__gcc_v8hi __builtin_ia32_packusdw128(__gcc_v4si, __gcc_v4si);
__gcc_v16qi __builtin_ia32_pblendvb128(__gcc_v16qi, __gcc_v16qi, __gcc_v16qi);
__gcc_v8hi __builtin_ia32_pblendw128(__gcc_v8hi, __gcc_v8hi, int);
__gcc_v2di __builtin_ia32_pcmpeqq(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_phminposuw128(__gcc_v8hi);
__gcc_v16qi __builtin_ia32_pmaxsb128(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_pmaxsd128(__gcc_v4si, __gcc_v4si);
__gcc_v4si __builtin_ia32_pmaxud128(__gcc_v4si, __gcc_v4si);
__gcc_v8hi __builtin_ia32_pmaxuw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_pminsb128(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_pminsd128(__gcc_v4si, __gcc_v4si);
__gcc_v4si __builtin_ia32_pminud128(__gcc_v4si, __gcc_v4si);
__gcc_v8hi __builtin_ia32_pminuw128(__gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_pmovsxbd128(__gcc_v16qi);
__gcc_v2di __builtin_ia32_pmovsxbq128(__gcc_v16qi);
__gcc_v8hi __builtin_ia32_pmovsxbw128(__gcc_v16qi);
__gcc_v2di __builtin_ia32_pmovsxdq128(__gcc_v4si);
__gcc_v4si __builtin_ia32_pmovsxwd128(__gcc_v8hi);
__gcc_v2di __builtin_ia32_pmovsxwq128(__gcc_v8hi);
__gcc_v4si __builtin_ia32_pmovzxbd128(__gcc_v16qi);
__gcc_v2di __builtin_ia32_pmovzxbq128(__gcc_v16qi);
__gcc_v8hi __builtin_ia32_pmovzxbw128(__gcc_v16qi);
__gcc_v2di __builtin_ia32_pmovzxdq128(__gcc_v4si);
__gcc_v4si __builtin_ia32_pmovzxwd128(__gcc_v8hi);
__gcc_v2di __builtin_ia32_pmovzxwq128(__gcc_v8hi);
__gcc_v2di __builtin_ia32_pmuldq128(__gcc_v4si, __gcc_v4si);
__gcc_v4si __builtin_ia32_pmulld128(__gcc_v4si, __gcc_v4si);
int __builtin_ia32_ptestc128(__gcc_v2di, __gcc_v2di);
int __builtin_ia32_ptestnzc128(__gcc_v2di, __gcc_v2di);
int __builtin_ia32_ptestz128(__gcc_v2di, __gcc_v2di);
__gcc_v2df __builtin_ia32_roundpd(__gcc_v2df, int);
__gcc_v4sf __builtin_ia32_roundps(__gcc_v4sf, int);
__gcc_v2df __builtin_ia32_roundsd(__gcc_v2df, __gcc_v2df, int);
__gcc_v4sf __builtin_ia32_roundss(__gcc_v4sf, __gcc_v4sf, int);
int __builtin_ia32_vec_ext___gcc_v16qi(__gcc_v16qi, const int);
float __builtin_ia32_vec_ext___gcc_v4sf(__gcc_v4sf, const int);
int __builtin_ia32_vec_ext___gcc_v4si(__gcc_v4si, const int);
__gcc_di __builtin_ia32_vec_ext___gcc_v2di(__gcc_v2di, const int);
__gcc_v16qi __builtin_ia32_pcmpestrm128(__gcc_v16qi, int, __gcc_v16qi, int, const int);
int __builtin_ia32_pcmpestri128(__gcc_v16qi, int, __gcc_v16qi, int, const int);
int __builtin_ia32_pcmpestria128(__gcc_v16qi, int, __gcc_v16qi, int, const int);
int __builtin_ia32_pcmpestric128(__gcc_v16qi, int, __gcc_v16qi, int, const int);
int __builtin_ia32_pcmpestrio128(__gcc_v16qi, int, __gcc_v16qi, int, const int);
int __builtin_ia32_pcmpestris128(__gcc_v16qi, int, __gcc_v16qi, int, const int);
int __builtin_ia32_pcmpestriz128(__gcc_v16qi, int, __gcc_v16qi, int, const int);
__gcc_v16qi __builtin_ia32_pcmpistrm128(__gcc_v16qi, __gcc_v16qi, const int);
int __builtin_ia32_pcmpistri128(__gcc_v16qi, __gcc_v16qi, const int);
int __builtin_ia32_pcmpistria128(__gcc_v16qi, __gcc_v16qi, const int);
int __builtin_ia32_pcmpistric128(__gcc_v16qi, __gcc_v16qi, const int);
int __builtin_ia32_pcmpistrio128(__gcc_v16qi, __gcc_v16qi, const int);
int __builtin_ia32_pcmpistris128(__gcc_v16qi, __gcc_v16qi, const int);
int __builtin_ia32_pcmpistriz128(__gcc_v16qi, __gcc_v16qi, const int);
__gcc_v2di __builtin_ia32_pcmpgtq(__gcc_v2di, __gcc_v2di);
unsigned __builtin_ia32_crc32qi(unsigned, unsigned char);
unsigned __builtin_ia32_crc32hi(unsigned, unsigned short);
unsigned __builtin_ia32_crc32si(unsigned, unsigned);
unsigned long long __builtin_ia32_crc32di(unsigned long long, unsigned long long);
int __builtin_popcount(unsigned int);
int __builtin_popcountl(unsigned long);
int __builtin_popcountll(unsigned long long);
__gcc_v4df __builtin_ia32_addpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_addps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_addsubpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_addsubps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_andnpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_andnps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_andpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_andps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_blendpd256(__gcc_v4df, __gcc_v4df, int);
__gcc_v8sf __builtin_ia32_blendps256(__gcc_v8sf, __gcc_v8sf, int);
__gcc_v4df __builtin_ia32_blendvpd256(__gcc_v4df, __gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_blendvps256(__gcc_v8sf, __gcc_v8sf, __gcc_v8sf);
__gcc_v2df __builtin_ia32_cmppd(__gcc_v2df, __gcc_v2df, int);
__gcc_v4df __builtin_ia32_cmppd256(__gcc_v4df, __gcc_v4df, int);
__gcc_v4sf __builtin_ia32_cmpps(__gcc_v4sf, __gcc_v4sf, int);
__gcc_v8sf __builtin_ia32_cmpps256(__gcc_v8sf, __gcc_v8sf, int);
__gcc_v2df __builtin_ia32_cmpsd(__gcc_v2df, __gcc_v2df, int);
__gcc_v4sf __builtin_ia32_cmpss(__gcc_v4sf, __gcc_v4sf, int);
__gcc_v4df __builtin_ia32_cvtdq2pd256(__gcc_v4si);
__gcc_v8sf __builtin_ia32_cvtdq2ps256(__gcc_v8si);
__gcc_v4si __builtin_ia32_cvtpd2dq256(__gcc_v4df);
__gcc_v4sf __builtin_ia32_cvtpd2ps256(__gcc_v4df);
__gcc_v8si __builtin_ia32_cvtps2dq256(__gcc_v8sf);
__gcc_v4df __builtin_ia32_cvtps2pd256(__gcc_v4sf);
__gcc_v4si __builtin_ia32_cvttpd2dq256(__gcc_v4df);
__gcc_v8si __builtin_ia32_cvttps2dq256(__gcc_v8sf);
__gcc_v4df __builtin_ia32_divpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_divps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v8sf __builtin_ia32_dpps256(__gcc_v8sf, __gcc_v8sf, int);
__gcc_v4df __builtin_ia32_haddpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_haddps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_hsubpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_hsubps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v32qi __builtin_ia32_lddqu256(const char*);
__gcc_v32qi __builtin_ia32_loaddqu256(const char*);
__gcc_v4df __builtin_ia32_loadupd256(const double*);
__gcc_v8sf __builtin_ia32_loadups256(const float*);
__gcc_v2df __builtin_ia32_maskloadpd(const __gcc_v2df*, __gcc_v2di);
__gcc_v4df __builtin_ia32_maskloadpd256(const __gcc_v4df*, __gcc_v4di);
__gcc_v4sf __builtin_ia32_maskloadps(const __gcc_v4sf*, __gcc_v4si);
__gcc_v8sf __builtin_ia32_maskloadps256(const __gcc_v8sf*, __gcc_v8si);
void __builtin_ia32_maskstorepd(__gcc_v2df*, __gcc_v2di, __gcc_v2df);
void __builtin_ia32_maskstorepd256(__gcc_v4df*, __gcc_v4di, __gcc_v4df);
void __builtin_ia32_maskstoreps(__gcc_v4sf*, __gcc_v4si, __gcc_v4sf);
void __builtin_ia32_maskstoreps256(__gcc_v8sf*, __gcc_v8si, __gcc_v8sf);
__gcc_v4df __builtin_ia32_maxpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_maxps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_minpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_minps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_movddup256(__gcc_v4df);
int __builtin_ia32_movmskpd256(__gcc_v4df);
int __builtin_ia32_movmskps256(__gcc_v8sf);
__gcc_v8sf __builtin_ia32_movshdup256(__gcc_v8sf);
__gcc_v8sf __builtin_ia32_movsldup256(__gcc_v8sf);
__gcc_v4df __builtin_ia32_mulpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_mulps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_orpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_orps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v2df __builtin_ia32_pd_pd256(__gcc_v4df);
__gcc_v4df __builtin_ia32_pd256_pd(__gcc_v2df);
__gcc_v4sf __builtin_ia32_ps_ps256(__gcc_v8sf);
__gcc_v8sf __builtin_ia32_ps256_ps(__gcc_v4sf);
int __builtin_ia32_ptestc256(__gcc_v4di,__gcc_v4di,...);
int __builtin_ia32_ptestnzc256(__gcc_v4di,__gcc_v4di,...);
int __builtin_ia32_ptestz256(__gcc_v4di,__gcc_v4di,...);
__gcc_v8sf __builtin_ia32_rcpps256(__gcc_v8sf);
__gcc_v4df __builtin_ia32_roundpd256(__gcc_v4df, int);
__gcc_v8sf __builtin_ia32_roundps256(__gcc_v8sf, int);
__gcc_v8sf __builtin_ia32_rsqrtps_nr256(__gcc_v8sf);
__gcc_v8sf __builtin_ia32_rsqrtps256(__gcc_v8sf);
__gcc_v4df __builtin_ia32_shufpd256(__gcc_v4df, __gcc_v4df, int);
__gcc_v8sf __builtin_ia32_shufps256(__gcc_v8sf, __gcc_v8sf, int);
__gcc_v4si __builtin_ia32_si_si256(__gcc_v8si);
__gcc_v8si __builtin_ia32_si256_si(__gcc_v4si);
__gcc_v4df __builtin_ia32_sqrtpd256(__gcc_v4df);
__gcc_v8sf __builtin_ia32_sqrtps_nr256(__gcc_v8sf);
__gcc_v8sf __builtin_ia32_sqrtps256(__gcc_v8sf);
void __builtin_ia32_storedqu256(char*, __gcc_v32qi);
void __builtin_ia32_storeupd256(double*, __gcc_v4df);
void __builtin_ia32_storeups256(float*, __gcc_v8sf);
__gcc_v4df __builtin_ia32_subpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_subps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_unpckhpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_unpckhps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_unpcklpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_unpcklps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_vbroadcastf128_pd256(const __gcc_v2df*);
__gcc_v8sf __builtin_ia32_vbroadcastf128_ps256(const __gcc_v4sf*);
__gcc_v4df __builtin_ia32_vbroadcastsd256(const double*);
__gcc_v4sf __builtin_ia32_vbroadcastss(const float*);
__gcc_v8sf __builtin_ia32_vbroadcastss256(const float*);
__gcc_v2df __builtin_ia32_vextractf128_pd256(__gcc_v4df, int);
__gcc_v4sf __builtin_ia32_vextractf128_ps256(__gcc_v8sf, int);
__gcc_v4si __builtin_ia32_vextractf128_si256(__gcc_v8si, int);
__gcc_v4df __builtin_ia32_vinsertf128_pd256(__gcc_v4df, __gcc_v2df, int);
__gcc_v8sf __builtin_ia32_vinsertf128_ps256(__gcc_v8sf, __gcc_v4sf, int);
__gcc_v8si __builtin_ia32_vinsertf128_si256(__gcc_v8si, __gcc_v4si, int);
__gcc_v4df __builtin_ia32_vperm2f128_pd256(__gcc_v4df, __gcc_v4df, int);
__gcc_v8sf __builtin_ia32_vperm2f128_ps256(__gcc_v8sf, __gcc_v8sf, int);
__gcc_v8si __builtin_ia32_vperm2f128_si256(__gcc_v8si, __gcc_v8si, int);
__gcc_v2df __builtin_ia32_vpermil2pd(__gcc_v2df,__gcc_v2df,__gcc_v2di,int);
__gcc_v4df __builtin_ia32_vpermil2pd256(__gcc_v4df,__gcc_v4df,__gcc_v4di,int);
__gcc_v4sf __builtin_ia32_vpermil2ps(__gcc_v4sf,__gcc_v4sf,__gcc_v4si,int);
__gcc_v8sf __builtin_ia32_vpermil2ps256(__gcc_v8sf,__gcc_v8sf,__gcc_v8si,int);
__gcc_v2df __builtin_ia32_vpermilpd(__gcc_v2df, int);
__gcc_v4df __builtin_ia32_vpermilpd256(__gcc_v4df, int);
__gcc_v4sf __builtin_ia32_vpermilps(__gcc_v4sf, int);
__gcc_v8sf __builtin_ia32_vpermilps256(__gcc_v8sf, int);
__gcc_v2df __builtin_ia32_vpermilvarpd(__gcc_v2df, __gcc_v2di);
__gcc_v4df __builtin_ia32_vpermilvarpd256(__gcc_v4df, __gcc_v4di);
__gcc_v4sf __builtin_ia32_vpermilvarps(__gcc_v4sf, __gcc_v4si);
__gcc_v8sf __builtin_ia32_vpermilvarps256(__gcc_v8sf, __gcc_v8si);
int __builtin_ia32_vtestcpd(__gcc_v2df,__gcc_v2df,...);
int __builtin_ia32_vtestcpd256(__gcc_v4df,__gcc_v4df,...);
int __builtin_ia32_vtestcps(__gcc_v4sf,__gcc_v4sf,...);
int __builtin_ia32_vtestcps256(__gcc_v8sf,__gcc_v8sf,...);
int __builtin_ia32_vtestnzcpd(__gcc_v2df,__gcc_v2df,...);
int __builtin_ia32_vtestnzcpd256(__gcc_v4df,__gcc_v4df,...);
int __builtin_ia32_vtestnzcps(__gcc_v4sf,__gcc_v4sf,...);
int __builtin_ia32_vtestnzcps256(__gcc_v8sf,__gcc_v8sf,...);
int __builtin_ia32_vtestzpd(__gcc_v2df,__gcc_v2df,...);
int __builtin_ia32_vtestzpd256(__gcc_v4df,__gcc_v4df,...);
int __builtin_ia32_vtestzps(__gcc_v4sf,__gcc_v4sf,...);
int __builtin_ia32_vtestzps256(__gcc_v8sf,__gcc_v8sf,...);
void __builtin_ia32_vzeroall();
void __builtin_ia32_vzeroupper();
__gcc_v4df __builtin_ia32_xorpd256(__gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_xorps256(__gcc_v8sf, __gcc_v8sf);
__gcc_v32qi __builtin_ia32_mpsadbw256(__gcc_v32qi, __gcc_v32qi, int);
__gcc_v32qi __builtin_ia32_pabsb256(__gcc_v32qi);
__gcc_v16hi __builtin_ia32_pabsw256(__gcc_v16hi);
__gcc_v8si __builtin_ia32_pabsd256(__gcc_v8si);
__gcc_v16hi __builtin_ia32_packssdw256(__gcc_v8si, __gcc_v8si);
__gcc_v32qi __builtin_ia32_packsswb256(__gcc_v16hi, __gcc_v16hi);
__gcc_v16hi __builtin_ia32_packusdw256(__gcc_v8si, __gcc_v8si);
__gcc_v32qi __builtin_ia32_packuswb256(__gcc_v16hi, __gcc_v16hi);
__gcc_v32qi __builtin_ia32_paddb256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_paddw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v8si __builtin_ia32_paddd256(__gcc_v8si, __gcc_v8si);
__gcc_v4di __builtin_ia32_paddq256(__gcc_v4di, __gcc_v4di);
__gcc_v32qi __builtin_ia32_paddsb256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_paddsw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v32qi __builtin_ia32_paddusb256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_paddusw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v4di __builtin_ia32_palignr256(__gcc_v4di,__gcc_v4di,int);
__gcc_v4di __builtin_ia32_andsi256(__gcc_v4di, __gcc_v4di);
__gcc_v4di __builtin_ia32_andnotsi256(__gcc_v4di, __gcc_v4di);
__gcc_v32qi __builtin_ia32_pavgb256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_pavgw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v32qi __builtin_ia32_pblendvb256(__gcc_v32qi, __gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_pblendw256(__gcc_v16hi, __gcc_v16hi, int);
__gcc_v32qi __builtin_ia32_pcmpeqb256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_pcmpeqw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v8si __builtin_ia32_pcmpeqd256(__gcc_v8si, __gcc_v8si);
__gcc_v4di __builtin_ia32_pcmpeqq256(__gcc_v4di, __gcc_v4di);
__gcc_v32qi __builtin_ia32_pcmpgtb256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_pcmpgtw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v8si __builtin_ia32_pcmpgtd256(__gcc_v8si, __gcc_v8si);
__gcc_v4di __builtin_ia32_pcmpgtq256(__gcc_v4di, __gcc_v4di);
__gcc_v16hi __builtin_ia32_phaddw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v8si __builtin_ia32_phaddd256(__gcc_v8si, __gcc_v8si);
__gcc_v16hi __builtin_ia32_phaddsw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v16hi __builtin_ia32_phsubw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v8si __builtin_ia32_phsubd256(__gcc_v8si, __gcc_v8si);
__gcc_v16hi __builtin_ia32_phsubsw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v16hi __builtin_ia32_pmaddubsw256(__gcc_v32qi, __gcc_v32qi);
__gcc_v8si __builtin_ia32_pmaddwd256(__gcc_v16hi, __gcc_v16hi);
__gcc_v32qi __builtin_ia32_pmaxsb256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_pmaxsw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v8si __builtin_ia32_pmaxsd256(__gcc_v8si, __gcc_v8si);
__gcc_v32qi __builtin_ia32_pmaxub256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_pmaxuw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v8si __builtin_ia32_pmaxud256(__gcc_v8si, __gcc_v8si);
__gcc_v32qi __builtin_ia32_pminsb256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_pminsw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v8si __builtin_ia32_pminsd256(__gcc_v8si, __gcc_v8si);
__gcc_v32qi __builtin_ia32_pminub256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_pminuw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v8si __builtin_ia32_pminud256(__gcc_v8si, __gcc_v8si);
int __builtin_ia32_pmovmskb256(__gcc_v32qi);
__gcc_v16hi __builtin_ia32_pmovsxbw256(__gcc_v16qi);
__gcc_v8si __builtin_ia32_pmovsxbd256(__gcc_v16qi);
__gcc_v4di __builtin_ia32_pmovsxbq256(__gcc_v16qi);
__gcc_v8si __builtin_ia32_pmovsxwd256(__gcc_v8hi);
__gcc_v4di __builtin_ia32_pmovsxwq256(__gcc_v8hi);
__gcc_v4di __builtin_ia32_pmovsxdq256(__gcc_v4si);
__gcc_v16hi __builtin_ia32_pmovzxbw256(__gcc_v16qi);
__gcc_v8si __builtin_ia32_pmovzxbd256(__gcc_v16qi);
__gcc_v4di __builtin_ia32_pmovzxbq256(__gcc_v16qi);
__gcc_v8si __builtin_ia32_pmovzxwd256(__gcc_v8hi);
__gcc_v4di __builtin_ia32_pmovzxwq256(__gcc_v8hi);
__gcc_v4di __builtin_ia32_pmovzxdq256(__gcc_v4si);
__gcc_v4di __builtin_ia32_pmuldq256(__gcc_v8si, __gcc_v8si);
__gcc_v16hi __builtin_ia32_pmulhrsw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v16hi __builtin_ia32_pmulhuw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v16hi __builtin_ia32_pmulhw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v16hi __builtin_ia32_pmullw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v8si __builtin_ia32_pmulld256(__gcc_v8si, __gcc_v8si);
__gcc_v4di __builtin_ia32_pmuludq256(__gcc_v8si, __gcc_v8si);
__gcc_v4di __builtin_ia32_por256(__gcc_v4di, __gcc_v4di);
__gcc_v16hi __builtin_ia32_psadbw256(__gcc_v32qi, __gcc_v32qi);
__gcc_v32qi __builtin_ia32_pshufb256(__gcc_v32qi, __gcc_v32qi);
__gcc_v8si __builtin_ia32_pshufd256(__gcc_v8si, int);
__gcc_v16hi __builtin_ia32_pshufhw256(__gcc_v16hi, int);
__gcc_v16hi __builtin_ia32_pshuflw256(__gcc_v16hi, int);
__gcc_v32qi __builtin_ia32_psignb256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_psignw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v8si __builtin_ia32_psignd256(__gcc_v8si, __gcc_v8si);
__gcc_v4di __builtin_ia32_pslldqi256(__gcc_v4di,int);
__gcc_v16hi __builtin_ia32_psllwi256(__gcc_v16hi,int);
__gcc_v16hi __builtin_ia32_psllw256(__gcc_v16hi,__gcc_v8hi);
__gcc_v8si __builtin_ia32_pslldi256(__gcc_v8si,int);
__gcc_v8si __builtin_ia32_pslld256(__gcc_v8si,__gcc_v4si);
__gcc_v4di __builtin_ia32_psllqi256(__gcc_v4di,int);
__gcc_v4di __builtin_ia32_psllq256(__gcc_v4di,__gcc_v2di);
__gcc_v16hi __builtin_ia32_psrawi256(__gcc_v16hi,int);
__gcc_v16hi __builtin_ia32_psraw256(__gcc_v16hi,__gcc_v8hi);
__gcc_v8si __builtin_ia32_psradi256(__gcc_v8si,int);
__gcc_v8si __builtin_ia32_psrad256(__gcc_v8si,__gcc_v4si);
__gcc_v4di __builtin_ia32_psrldqi256(__gcc_v4di, int);
__gcc_v16hi __builtin_ia32_psrlwi256(__gcc_v16hi,int);
__gcc_v16hi __builtin_ia32_psrlw256(__gcc_v16hi,__gcc_v8hi);
__gcc_v8si __builtin_ia32_psrldi256(__gcc_v8si,int);
__gcc_v8si __builtin_ia32_psrld256(__gcc_v8si,__gcc_v4si);
__gcc_v4di __builtin_ia32_psrlqi256(__gcc_v4di,int);
__gcc_v4di __builtin_ia32_psrlq256(__gcc_v4di,__gcc_v2di);
__gcc_v32qi __builtin_ia32_psubb256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_psubw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v8si __builtin_ia32_psubd256(__gcc_v8si, __gcc_v8si);
__gcc_v4di __builtin_ia32_psubq256(__gcc_v4di, __gcc_v4di);
__gcc_v32qi __builtin_ia32_psubsb256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_psubsw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v32qi __builtin_ia32_psubusb256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_psubusw256(__gcc_v16hi, __gcc_v16hi);
__gcc_v32qi __builtin_ia32_punpckhbw256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_punpckhwd256(__gcc_v16hi, __gcc_v16hi);
__gcc_v8si __builtin_ia32_punpckhdq256(__gcc_v8si, __gcc_v8si);
__gcc_v4di __builtin_ia32_punpckhqdq256(__gcc_v4di, __gcc_v4di);
__gcc_v32qi __builtin_ia32_punpcklbw256(__gcc_v32qi, __gcc_v32qi);
__gcc_v16hi __builtin_ia32_punpcklwd256(__gcc_v16hi, __gcc_v16hi);
__gcc_v8si __builtin_ia32_punpckldq256(__gcc_v8si, __gcc_v8si);
__gcc_v4di __builtin_ia32_punpcklqdq256(__gcc_v4di, __gcc_v4di);
__gcc_v4di __builtin_ia32_pxor256(__gcc_v4di, __gcc_v4di);
__gcc_v4di __builtin_ia32_movntdqa256(__gcc_v4di*);
__gcc_v4sf __builtin_ia32_vbroadcastss_ps(__gcc_v4sf);
__gcc_v8sf __builtin_ia32_vbroadcastss_ps256(__gcc_v4sf);
__gcc_v4df __builtin_ia32_vbroadcastsd_pd256(__gcc_v2df);
__gcc_v4di __builtin_ia32_vbroadcastsi256(__gcc_v2di);
__gcc_v4si __builtin_ia32_pblendd128(__gcc_v4si, __gcc_v4si, int);
__gcc_v8si __builtin_ia32_pblendd256(__gcc_v8si, __gcc_v8si, int);
__gcc_v32qi __builtin_ia32_pbroadcastb256(__gcc_v16qi);
__gcc_v16hi __builtin_ia32_pbroadcastw256(__gcc_v8hi);
__gcc_v8si __builtin_ia32_pbroadcastd256(__gcc_v4si);
__gcc_v4di __builtin_ia32_pbroadcastq256(__gcc_v2di);
__gcc_v16qi __builtin_ia32_pbroadcastb128(__gcc_v16qi);
__gcc_v8hi __builtin_ia32_pbroadcastw128(__gcc_v8hi);
__gcc_v4si __builtin_ia32_pbroadcastd128(__gcc_v4si);
__gcc_v2di __builtin_ia32_pbroadcastq128(__gcc_v2di);
__gcc_v8si __builtin_ia32_permvarsi256(__gcc_v8si, __gcc_v8si);
__gcc_v4df __builtin_ia32_permdf256(__gcc_v4df, int);
__gcc_v8sf __builtin_ia32_permvarsf256(__gcc_v8sf, __gcc_v8si);
__gcc_v4di __builtin_ia32_permdi256(__gcc_v4di, int);
__gcc_v4di __builtin_ia32_permti256(__gcc_v4di, __gcc_v4di, int);
__gcc_v2di __builtin_ia32_extract128i256(__gcc_v4di, int);
__gcc_v4di __builtin_ia32_insert128i256(__gcc_v4di, __gcc_v2di, int);
__gcc_v8si __builtin_ia32_maskloadd256(const __gcc_v8si*, __gcc_v8si);
__gcc_v4di __builtin_ia32_maskloadq256(const __gcc_v4di*, __gcc_v4di);
__gcc_v4si __builtin_ia32_maskloadd(const __gcc_v4si*, __gcc_v4si);
__gcc_v2di __builtin_ia32_maskloadq(const __gcc_v2di*, __gcc_v2di);
void __builtin_ia32_maskstored256(__gcc_v8si*, __gcc_v8si, __gcc_v8si);
void __builtin_ia32_maskstoreq256(__gcc_v4di*, __gcc_v4di, __gcc_v4di);
void __builtin_ia32_maskstored(__gcc_v4si*, __gcc_v4si, __gcc_v4si);
void __builtin_ia32_maskstoreq(__gcc_v2di*, __gcc_v2di, __gcc_v2di);
__gcc_v8si __builtin_ia32_psll__gcc_v8si(__gcc_v8si,__gcc_v8si);
__gcc_v4si __builtin_ia32_psll__gcc_v4si(__gcc_v4si,__gcc_v4si);
__gcc_v4di __builtin_ia32_psll__gcc_v4di(__gcc_v4di,__gcc_v4di);
__gcc_v2di __builtin_ia32_psll__gcc_v2di(__gcc_v2di,__gcc_v2di);
__gcc_v8si __builtin_ia32_psra__gcc_v8si(__gcc_v8si,__gcc_v8si);
__gcc_v4si __builtin_ia32_psra__gcc_v4si(__gcc_v4si,__gcc_v4si);
__gcc_v8si __builtin_ia32_psrl__gcc_v8si(__gcc_v8si,__gcc_v8si);
__gcc_v4si __builtin_ia32_psrl__gcc_v4si(__gcc_v4si,__gcc_v4si);
__gcc_v4di __builtin_ia32_psrl__gcc_v4di(__gcc_v4di,__gcc_v4di);
__gcc_v2di __builtin_ia32_psrl__gcc_v2di(__gcc_v2di,__gcc_v2di);
__gcc_v2df __builtin_ia32_gathersi__gcc_v2df(__gcc_v2df, const double*,__gcc_v4si,__gcc_v2df,int);
__gcc_v4df __builtin_ia32_gathersi__gcc_v4df(__gcc_v4df, const double*,__gcc_v4si,__gcc_v4df,int);
__gcc_v2df __builtin_ia32_gatherdi__gcc_v2df(__gcc_v2df, const double*,__gcc_v2di,__gcc_v2df,int);
__gcc_v4df __builtin_ia32_gatherdi__gcc_v4df(__gcc_v4df, const double*,__gcc_v4di,__gcc_v4df,int);
__gcc_v4sf __builtin_ia32_gathersi__gcc_v4sf(__gcc_v4sf, const float*,__gcc_v4si,__gcc_v4sf,int);
__gcc_v8sf __builtin_ia32_gathersi__gcc_v8sf(__gcc_v8sf, const float*,__gcc_v8si,__gcc_v8sf,int);
__gcc_v4sf __builtin_ia32_gatherdi__gcc_v4sf(__gcc_v4sf, const float*,__gcc_v2di,__gcc_v4sf,int);
__gcc_v4sf __builtin_ia32_gatherdi__gcc_v4sf256(__gcc_v4sf, const float*,__gcc_v4di,__gcc_v4sf,int);
__gcc_v2di __builtin_ia32_gathersi__gcc_v2di(__gcc_v2di, const long long int*,__gcc_v4si,__gcc_v2di,int);
__gcc_v4di __builtin_ia32_gathersi__gcc_v4di(__gcc_v4di, const long long int*,__gcc_v4si,__gcc_v4di,int);
__gcc_v2di __builtin_ia32_gatherdi__gcc_v2di(__gcc_v2di, const long long int*,__gcc_v2di,__gcc_v2di,int);
__gcc_v4di __builtin_ia32_gatherdi__gcc_v4di(__gcc_v4di, const long long int*,__gcc_v4di,__gcc_v4di,int);
__gcc_v4si __builtin_ia32_gathersi__gcc_v4si(__gcc_v4si, const int*,__gcc_v4si,__gcc_v4si,int);
__gcc_v8si __builtin_ia32_gathersi__gcc_v8si(__gcc_v8si, const int*,__gcc_v8si,__gcc_v8si,int);
__gcc_v4si __builtin_ia32_gatherdi__gcc_v4si(__gcc_v4si, const int*,__gcc_v2di,__gcc_v4si,int);
__gcc_v4si __builtin_ia32_gatherdi__gcc_v4si256(__gcc_v4si, const int*,__gcc_v4di,__gcc_v4si,int);
__gcc_v2di __builtin_ia32_aesenc128(__gcc_v2di, __gcc_v2di);
__gcc_v2di __builtin_ia32_aesenclast128(__gcc_v2di, __gcc_v2di);
__gcc_v2di __builtin_ia32_aesdec128(__gcc_v2di, __gcc_v2di);
__gcc_v2di __builtin_ia32_aesdeclast128(__gcc_v2di, __gcc_v2di);
__gcc_v2di __builtin_ia32_aeskeygenassist128(__gcc_v2di, const int);
__gcc_v2di __builtin_ia32_aesimc128(__gcc_v2di);
__gcc_v2di __builtin_ia32_pclmulqdq128(__gcc_v2di, __gcc_v2di, const int);
unsigned __builtin_ia32_rdfsbase32();
unsigned long long __builtin_ia32_rdfsbase64();
unsigned __builtin_ia32_rdgsbase32();
unsigned long long __builtin_ia32_rdgsbase64();
void _writefsbase_u32(unsigned int);
void _writefsbase_u64(unsigned long long);
void _writegsbase_u32(unsigned int);
void _writegsbase_u64(unsigned long long);
unsigned int __builtin_ia32_rdrand16_step(unsigned short*);
unsigned int __builtin_ia32_rdrand32_step(unsigned int*);
unsigned int __builtin_ia32_rdrand64_step(unsigned long long*);
void __builtin_ia32_movntsd(double*, __gcc_v2df);
void __builtin_ia32_movntss(float*, __gcc_v4sf);
__gcc_v2di __builtin_ia32_extrq (__gcc_v2di, __gcc_v16qi);
__gcc_v2di __builtin_ia32_extrqi(__gcc_v2di, unsigned, unsigned);
__gcc_v2di __builtin_ia32_insertq(__gcc_v2di, __gcc_v2di);
__gcc_v2di __builtin_ia32_insertqi(__gcc_v2di, __gcc_v2di, unsigned, unsigned);
__gcc_v2df __builtin_ia32_vfrczpd(__gcc_v2df);
__gcc_v4sf __builtin_ia32_vfrczps(__gcc_v4sf);
__gcc_v2df __builtin_ia32_vfrczsd(__gcc_v2df);
__gcc_v4sf __builtin_ia32_vfrczss(__gcc_v4sf);
__gcc_v4df __builtin_ia32_vfrczpd256(__gcc_v4df);
__gcc_v8sf __builtin_ia32_vfrczps256(__gcc_v8sf);
__gcc_v2di __builtin_ia32_vpcmov(__gcc_v2di, __gcc_v2di, __gcc_v2di);
__gcc_v2di __builtin_ia32_vpcmov_v2di(__gcc_v2di, __gcc_v2di, __gcc_v2di);
__gcc_v4si __builtin_ia32_vpcmov_v4si(__gcc_v4si, __gcc_v4si, __gcc_v4si);
__gcc_v8hi __builtin_ia32_vpcmov_v8hi(__gcc_v8hi, __gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_vpcmov_v16qi(__gcc_v16qi, __gcc_v16qi, __gcc_v16qi);
__gcc_v2df __builtin_ia32_vpcmov_v2df(__gcc_v2df, __gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_vpcmov_v4sf(__gcc_v4sf, __gcc_v4sf, __gcc_v4sf);
__gcc_v4di __builtin_ia32_vpcmov_v4di256(__gcc_v4di, __gcc_v4di, __gcc_v4di);
__gcc_v8si __builtin_ia32_vpcmov_v8si256(__gcc_v8si, __gcc_v8si, __gcc_v8si);
__gcc_v16hi __builtin_ia32_vpcmov_v16hi256(__gcc_v16hi, __gcc_v16hi, __gcc_v16hi);
__gcc_v32qi __builtin_ia32_vpcmov_v32qi256(__gcc_v32qi, __gcc_v32qi, __gcc_v32qi);
__gcc_v4df __builtin_ia32_vpcmov___gcc_v4df256(__gcc_v4df, __gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_vpcmov___gcc_v8sf256(__gcc_v8sf, __gcc_v8sf, __gcc_v8sf);
__gcc_v16qi __builtin_ia32_vpcomeqb(__gcc_v16qi, __gcc_v16qi);
__gcc_v8hi __builtin_ia32_vpcomeqw(__gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_vpcomeqd(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomeqq(__gcc_v2di, __gcc_v2di);
__gcc_v16qi __builtin_ia32_vpcomequb(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomequd(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomequq(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_vpcomequw(__gcc_v8hi, __gcc_v8hi);
__gcc_v8hi __builtin_ia32_vpcomeqw(__gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_vpcomfalseb(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomfalsed(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomfalseq(__gcc_v2di, __gcc_v2di);
__gcc_v16qi __builtin_ia32_vpcomfalseub(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomfalseud(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomfalseuq(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_vpcomfalseuw(__gcc_v8hi, __gcc_v8hi);
__gcc_v8hi __builtin_ia32_vpcomfalsew(__gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_vpcomgeb(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomged(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomgeq(__gcc_v2di, __gcc_v2di);
__gcc_v16qi __builtin_ia32_vpcomgeub(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomgeud(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomgeuq(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_vpcomgeuw(__gcc_v8hi, __gcc_v8hi);
__gcc_v8hi __builtin_ia32_vpcomgew(__gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_vpcomgtb(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomgtd(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomgtq(__gcc_v2di, __gcc_v2di);
__gcc_v16qi __builtin_ia32_vpcomgtub(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomgtud(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomgtuq(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_vpcomgtuw(__gcc_v8hi, __gcc_v8hi);
__gcc_v8hi __builtin_ia32_vpcomgtw(__gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_vpcomleb(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomled(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomleq(__gcc_v2di, __gcc_v2di);
__gcc_v16qi __builtin_ia32_vpcomleub(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomleud(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomleuq(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_vpcomleuw(__gcc_v8hi, __gcc_v8hi);
__gcc_v8hi __builtin_ia32_vpcomlew(__gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_vpcomltb(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomltd(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomltq(__gcc_v2di, __gcc_v2di);
__gcc_v16qi __builtin_ia32_vpcomltub(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomltud(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomltuq(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_vpcomltuw(__gcc_v8hi, __gcc_v8hi);
__gcc_v8hi __builtin_ia32_vpcomltw(__gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_vpcomneb(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomned(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomneq(__gcc_v2di, __gcc_v2di);
__gcc_v16qi __builtin_ia32_vpcomneub(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomneud(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomneuq(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_vpcomneuw(__gcc_v8hi, __gcc_v8hi);
__gcc_v8hi __builtin_ia32_vpcomnew(__gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_vpcomtrueb(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomtrued(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomtrueq(__gcc_v2di, __gcc_v2di);
__gcc_v16qi __builtin_ia32_vpcomtrueub(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpcomtrueud(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpcomtrueuq(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_vpcomtrueuw(__gcc_v8hi, __gcc_v8hi);
__gcc_v8hi __builtin_ia32_vpcomtruew(__gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_vphaddbd(__gcc_v16qi);
__gcc_v2di __builtin_ia32_vphaddbq(__gcc_v16qi);
__gcc_v8hi __builtin_ia32_vphaddbw(__gcc_v16qi);
__gcc_v2di __builtin_ia32_vphadddq(__gcc_v4si);
__gcc_v4si __builtin_ia32_vphaddubd(__gcc_v16qi);
__gcc_v2di __builtin_ia32_vphaddubq(__gcc_v16qi);
__gcc_v8hi __builtin_ia32_vphaddubw(__gcc_v16qi);
__gcc_v2di __builtin_ia32_vphaddudq(__gcc_v4si);
__gcc_v4si __builtin_ia32_vphadduwd(__gcc_v8hi);
__gcc_v2di __builtin_ia32_vphadduwq(__gcc_v8hi);
__gcc_v4si __builtin_ia32_vphaddwd(__gcc_v8hi);
__gcc_v2di __builtin_ia32_vphaddwq(__gcc_v8hi);
__gcc_v8hi __builtin_ia32_vphsubbw(__gcc_v16qi);
__gcc_v2di __builtin_ia32_vphsubdq(__gcc_v4si);
__gcc_v4si __builtin_ia32_vphsubwd(__gcc_v8hi);
__gcc_v4si __builtin_ia32_vpmacsdd(__gcc_v4si, __gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpmacsdqh(__gcc_v4si, __gcc_v4si, __gcc_v2di);
__gcc_v2di __builtin_ia32_vpmacsdql(__gcc_v4si, __gcc_v4si, __gcc_v2di);
__gcc_v4si __builtin_ia32_vpmacssdd(__gcc_v4si, __gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpmacssdqh(__gcc_v4si, __gcc_v4si, __gcc_v2di);
__gcc_v2di __builtin_ia32_vpmacssdql(__gcc_v4si, __gcc_v4si, __gcc_v2di);
__gcc_v4si __builtin_ia32_vpmacsswd(__gcc_v8hi, __gcc_v8hi, __gcc_v4si);
__gcc_v8hi __builtin_ia32_vpmacssww(__gcc_v8hi, __gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_vpmacswd(__gcc_v8hi, __gcc_v8hi, __gcc_v4si);
__gcc_v8hi __builtin_ia32_vpmacsww(__gcc_v8hi, __gcc_v8hi, __gcc_v8hi);
__gcc_v4si __builtin_ia32_vpmadcsswd(__gcc_v8hi, __gcc_v8hi, __gcc_v4si);
__gcc_v4si __builtin_ia32_vpmadcswd(__gcc_v8hi, __gcc_v8hi, __gcc_v4si);
__gcc_v16qi __builtin_ia32_vpperm(__gcc_v16qi, __gcc_v16qi, __gcc_v16qi);
__gcc_v16qi __builtin_ia32_vprotb(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vprotd(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vprotq(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_vprotw(__gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_vpshab(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpshad(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpshaq(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_vpshaw(__gcc_v8hi, __gcc_v8hi);
__gcc_v16qi __builtin_ia32_vpshlb(__gcc_v16qi, __gcc_v16qi);
__gcc_v4si __builtin_ia32_vpshld(__gcc_v4si, __gcc_v4si);
__gcc_v2di __builtin_ia32_vpshlq(__gcc_v2di, __gcc_v2di);
__gcc_v8hi __builtin_ia32_vpshlw(__gcc_v8hi, __gcc_v8hi);
__gcc_v2df __builtin_ia32_fmaddpd(__gcc_v2df, __gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_fmaddps(__gcc_v4sf, __gcc_v4sf, __gcc_v4sf);
__gcc_v2df __builtin_ia32_fmaddsd(__gcc_v2df, __gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_fmaddss(__gcc_v4sf, __gcc_v4sf, __gcc_v4sf);
__gcc_v2df __builtin_ia32_fmsubpd(__gcc_v2df, __gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_fmsubps(__gcc_v4sf, __gcc_v4sf, __gcc_v4sf);
__gcc_v2df __builtin_ia32_fmsubsd(__gcc_v2df, __gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_fmsubss(__gcc_v4sf, __gcc_v4sf, __gcc_v4sf);
__gcc_v2df __builtin_ia32_fnmaddpd(__gcc_v2df, __gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_fnmaddps(__gcc_v4sf, __gcc_v4sf, __gcc_v4sf);
__gcc_v2df __builtin_ia32_fnmaddsd(__gcc_v2df, __gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_fnmaddss(__gcc_v4sf, __gcc_v4sf, __gcc_v4sf);
__gcc_v2df __builtin_ia32_fnmsubpd(__gcc_v2df, __gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_fnmsubps(__gcc_v4sf, __gcc_v4sf, __gcc_v4sf);
__gcc_v2df __builtin_ia32_fnmsubsd(__gcc_v2df, __gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_fnmsubss(__gcc_v4sf, __gcc_v4sf, __gcc_v4sf);
__gcc_v2df __builtin_ia32_fmaddsubpd (__gcc_v2df, __gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_fmaddsubps (__gcc_v4sf, __gcc_v4sf, __gcc_v4sf);
__gcc_v2df __builtin_ia32_fmsubaddpd (__gcc_v2df, __gcc_v2df, __gcc_v2df);
__gcc_v4sf __builtin_ia32_fmsubaddps (__gcc_v4sf, __gcc_v4sf, __gcc_v4sf);
__gcc_v4df __builtin_ia32_fmaddpd256(__gcc_v4df, __gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_fmaddps256(__gcc_v8sf, __gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_fmsubpd256(__gcc_v4df, __gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_fmsubps256(__gcc_v8sf, __gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_fnmaddpd256(__gcc_v4df, __gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_fnmaddps256(__gcc_v8sf, __gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_fnmsubpd256(__gcc_v4df, __gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_fnmsubps256(__gcc_v8sf, __gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_fmaddsubpd256(__gcc_v4df, __gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_fmaddsubps256(__gcc_v8sf, __gcc_v8sf, __gcc_v8sf);
__gcc_v4df __builtin_ia32_fmsubaddpd256(__gcc_v4df, __gcc_v4df, __gcc_v4df);
__gcc_v8sf __builtin_ia32_fmsubaddps256(__gcc_v8sf, __gcc_v8sf, __gcc_v8sf);
void __builtin_ia32_llwpcb16(void*);
void __builtin_ia32_llwpcb32(void*);
void __builtin_ia32_llwpcb64(void*);
//void* __builtin_ia32_llwpcb16(void);
//void* __builtin_ia32_llwpcb32(void);
//void* __builtin_ia32_llwpcb64(void);
void __builtin_ia32_lwpval16(unsigned short, unsigned int, unsigned short);
void __builtin_ia32_lwpval32(unsigned, unsigned, unsigned);
void __builtin_ia32_lwpval64(unsigned long long, unsigned, unsigned);
unsigned char __builtin_ia32_lwpins16(unsigned short, unsigned int, unsigned short);
unsigned char __builtin_ia32_lwpins32(unsigned, unsigned, unsigned);
unsigned char __builtin_ia32_lwpins64(unsigned long long, unsigned, unsigned);
unsigned __builtin_ia32_bextr_u32(unsigned, unsigned);
unsigned long long __builtin_ia32_bextr_u64(unsigned long long, unsigned long long);
unsigned int _bzhi_u32(unsigned int, unsigned int);
unsigned int _pdep_u32(unsigned int, unsigned int);
unsigned int _pext_u32(unsigned int, unsigned int);
unsigned long long _bzhi_u64(unsigned long long, unsigned long long);
unsigned long long _pdep_u64(unsigned long long, unsigned long long);
unsigned long long _pext_u64(unsigned long long, unsigned long long);
unsigned short __builtin_ia32_lzcnt_16(unsigned short);
unsigned __builtin_ia32_lzcnt_u32(unsigned);
unsigned long long __builtin_ia32_lzcnt_u64(unsigned long long);
unsigned __builtin_ia32_bextri_u32(unsigned, unsigned);
unsigned long long __builtin_ia32_bextri_u64(unsigned long long, unsigned long long);
void __builtin_ia32_femms();
__gcc_v8qi __builtin_ia32_pavgusb(__gcc_v8qi, __gcc_v8qi);
__gcc_v2si __builtin_ia32_pf2id(__gcc_v2sf);
__gcc_v2sf __builtin_ia32_pfacc(__gcc_v2sf, __gcc_v2sf);
__gcc_v2sf __builtin_ia32_pfadd(__gcc_v2sf, __gcc_v2sf);
__gcc_v2si __builtin_ia32_pfcmpeq(__gcc_v2sf, __gcc_v2sf);
__gcc_v2si __builtin_ia32_pfcmpge(__gcc_v2sf, __gcc_v2sf);
__gcc_v2si __builtin_ia32_pfcmpgt(__gcc_v2sf, __gcc_v2sf);
__gcc_v2sf __builtin_ia32_pfmax(__gcc_v2sf, __gcc_v2sf);
__gcc_v2sf __builtin_ia32_pfmin(__gcc_v2sf, __gcc_v2sf);
__gcc_v2sf __builtin_ia32_pfmul(__gcc_v2sf, __gcc_v2sf);
__gcc_v2sf __builtin_ia32_pfrcp(__gcc_v2sf);
__gcc_v2sf __builtin_ia32_pfrcpit1(__gcc_v2sf, __gcc_v2sf);
__gcc_v2sf __builtin_ia32_pfrcpit2(__gcc_v2sf, __gcc_v2sf);
__gcc_v2sf __builtin_ia32_pfrsqrt(__gcc_v2sf);
__gcc_v2sf __builtin_ia32_pfrsqrtit1(__gcc_v2sf, __gcc_v2sf);
__gcc_v2sf __builtin_ia32_pfsub(__gcc_v2sf, __gcc_v2sf);
__gcc_v2sf __builtin_ia32_pfsubr(__gcc_v2sf, __gcc_v2sf);
__gcc_v2sf __builtin_ia32_pi2fd(__gcc_v2si);
__gcc_v4hi __builtin_ia32_pmulhrw(__gcc_v4hi, __gcc_v4hi);
__gcc_v2si __builtin_ia32_pf2iw(__gcc_v2sf);
__gcc_v2sf __builtin_ia32_pfnacc(__gcc_v2sf, __gcc_v2sf);
__gcc_v2sf __builtin_ia32_pfpnacc(__gcc_v2sf, __gcc_v2sf);
__gcc_v2sf __builtin_ia32_pi2fw(__gcc_v2si);
__gcc_v2sf __builtin_ia32_pswapdsf(__gcc_v2sf);
__gcc_v2si __builtin_ia32_pswapdsi(__gcc_v2si);

// unknown!

__gcc_v4sf __builtin_ia32_cmpnltss(__gcc_v4sf, __gcc_v4sf);
int __builtin_ia32_comeqpd();
int __builtin_ia32_comeqps();
int __builtin_ia32_comeqsd();
int __builtin_ia32_comeqss();
int __builtin_ia32_comfalsepd();
int __builtin_ia32_comfalseps();
int __builtin_ia32_comfalsesd();
int __builtin_ia32_comfalsess();
int __builtin_ia32_comgepd();
int __builtin_ia32_comgeps();
int __builtin_ia32_comgesd();
int __builtin_ia32_comgess();
int __builtin_ia32_comgtpd();
int __builtin_ia32_comgtps();
int __builtin_ia32_comgtsd();
int __builtin_ia32_comgtss();
int __builtin_ia32_comlepd();
int __builtin_ia32_comleps();
int __builtin_ia32_comlesd();
int __builtin_ia32_comless();
int __builtin_ia32_comltpd();
int __builtin_ia32_comltps();
int __builtin_ia32_comltsd();
int __builtin_ia32_comltss();
int __builtin_ia32_comneqpd();
int __builtin_ia32_comneqps();
int __builtin_ia32_comneqsd();
int __builtin_ia32_comneqss();
int __builtin_ia32_comordpd();
int __builtin_ia32_comordps();
int __builtin_ia32_comordsd();
int __builtin_ia32_comordss();
int __builtin_ia32_comtruepd();
int __builtin_ia32_comtrueps();
int __builtin_ia32_comtruesd();
int __builtin_ia32_comtruess();
int __builtin_ia32_comueqpd();
int __builtin_ia32_comueqps();
int __builtin_ia32_comueqsd();
int __builtin_ia32_comueqss();
int __builtin_ia32_comuneqpd();
int __builtin_ia32_comuneqps();
int __builtin_ia32_comuneqsd();
int __builtin_ia32_comuneqss();
int __builtin_ia32_comungepd();
int __builtin_ia32_comungeps();
int __builtin_ia32_comungesd();
int __builtin_ia32_comungess();
int __builtin_ia32_comungtpd();
int __builtin_ia32_comungtps();
int __builtin_ia32_comungtsd();
int __builtin_ia32_comungtss();
int __builtin_ia32_comunlepd();
int __builtin_ia32_comunleps();
int __builtin_ia32_comunlesd();
int __builtin_ia32_comunless();
int __builtin_ia32_comunltpd();
int __builtin_ia32_comunltps();
int __builtin_ia32_comunltsd();
int __builtin_ia32_comunltss();
int __builtin_ia32_comunordpd();
int __builtin_ia32_comunordps();
int __builtin_ia32_comunordsd();
int __builtin_ia32_comunordss();
int __builtin_ia32_frczpd();
int __builtin_ia32_frczps();
int __builtin_ia32_frczsd();
int __builtin_ia32_frczss();
int __builtin_ia32_pcmov();
int __builtin_ia32_pcomeqb();
int __builtin_ia32_pcomeqd();
int __builtin_ia32_pcomeqq();
int __builtin_ia32_pcomequb();
int __builtin_ia32_pcomequd();
int __builtin_ia32_pcomequq();
int __builtin_ia32_pcomequw();
int __builtin_ia32_pcomeqw();
int __builtin_ia32_pcomfalseb();
int __builtin_ia32_pcomfalsed();
int __builtin_ia32_pcomfalseq();
int __builtin_ia32_pcomfalseub();
int __builtin_ia32_pcomfalseud();
int __builtin_ia32_pcomfalseuq();
int __builtin_ia32_pcomfalseuw();
int __builtin_ia32_pcomfalsew();
int __builtin_ia32_pcomgeb();
int __builtin_ia32_pcomged();
int __builtin_ia32_pcomgeq();
int __builtin_ia32_pcomgeub();
int __builtin_ia32_pcomgeud();
int __builtin_ia32_pcomgeuq();
int __builtin_ia32_pcomgeuw();
int __builtin_ia32_pcomgew();
int __builtin_ia32_pcomgtb();
int __builtin_ia32_pcomgtd();
int __builtin_ia32_pcomgtq();
int __builtin_ia32_pcomgtub();
int __builtin_ia32_pcomgtud();
int __builtin_ia32_pcomgtuq();
int __builtin_ia32_pcomgtuw();
int __builtin_ia32_pcomgtw();
int __builtin_ia32_pcomleb();
int __builtin_ia32_pcomled();
int __builtin_ia32_pcomleq();
int __builtin_ia32_pcomleub();
int __builtin_ia32_pcomleud();
int __builtin_ia32_pcomleuq();
int __builtin_ia32_pcomleuw();
int __builtin_ia32_pcomlew();
int __builtin_ia32_pcomltb();
int __builtin_ia32_pcomltd();
int __builtin_ia32_pcomltq();
int __builtin_ia32_pcomltub();
int __builtin_ia32_pcomltud();
int __builtin_ia32_pcomltuq();
int __builtin_ia32_pcomltuw();
int __builtin_ia32_pcomltw();
int __builtin_ia32_pcomneqb();
int __builtin_ia32_pcomneqd();
int __builtin_ia32_pcomneqq();
int __builtin_ia32_pcomnequb();
int __builtin_ia32_pcomnequd();
int __builtin_ia32_pcomnequq();
int __builtin_ia32_pcomnequw();
int __builtin_ia32_pcomneqw();
int __builtin_ia32_pcomtrueb();
int __builtin_ia32_pcomtrued();
int __builtin_ia32_pcomtrueq();
int __builtin_ia32_pcomtrueub();
int __builtin_ia32_pcomtrueud();
int __builtin_ia32_pcomtrueuq();
int __builtin_ia32_pcomtrueuw();
int __builtin_ia32_pcomtruew();
int __builtin_ia32_permpd();
int __builtin_ia32_permps();
int __builtin_ia32_phaddbd();
int __builtin_ia32_phaddbq();
int __builtin_ia32_phaddbw();
int __builtin_ia32_phadddq();
int __builtin_ia32_phaddubd();
int __builtin_ia32_phaddubq();
int __builtin_ia32_phaddubw();
int __builtin_ia32_phaddudq();
int __builtin_ia32_phadduwd();
int __builtin_ia32_phadduwq();
int __builtin_ia32_phaddwd();
int __builtin_ia32_phaddwq();
int __builtin_ia32_phsubbw();
int __builtin_ia32_phsubdq();
int __builtin_ia32_phsubwd();
int __builtin_ia32_pmacsdd();
int __builtin_ia32_pmacsdqh();
int __builtin_ia32_pmacsdql();
int __builtin_ia32_pmacssdd();
int __builtin_ia32_pmacssdqh();
int __builtin_ia32_pmacssdql();
int __builtin_ia32_pmacsswd();
int __builtin_ia32_pmacssww();
int __builtin_ia32_pmacswd();
int __builtin_ia32_pmacsww();
int __builtin_ia32_pmadcsswd();
int __builtin_ia32_pmadcswd();
int __builtin_ia32_pperm();
int __builtin_ia32_protb();
int __builtin_ia32_protd();
int __builtin_ia32_protq();
int __builtin_ia32_protw();
int __builtin_ia32_pshab();
int __builtin_ia32_pshad();
int __builtin_ia32_pshaq();
int __builtin_ia32_pshaw();
int __builtin_ia32_pshlb();
int __builtin_ia32_pshld();
int __builtin_ia32_pshlq();
int __builtin_ia32_pshlw();
double __builtin_ia32_vec_ext_v2df(__gcc_v2df, int);
__gcc_di __builtin_ia32_vec_ext_v2di(__gcc_v2di, int);
float __builtin_ia32_vec_ext_v4sf(__gcc_v4sf, int);
int __builtin_ia32_vec_ext_v4si(__gcc_v4si, int);
